library(liftOver)
library(ChIPpeakAnno)

###################################################################################################
###################################### COMPARING PEAKS ############################################
###################################################################################################

## All peaks
system("less enhancers/dunnart_enhancer_peaks.narrowPeak | awk '{print $1,$2,$3}' > dunnart.enhancer_peaks_coord.bed",intern=TRUE)
system("less promoters/clustered/dunnart.clustered.narrowPeak | awk '{print $1,$2,$3}' > promoters/clustered/dunnart.promoter_peaks_coord.bed",intern=TRUE)

system("liftOver enhancers/dunnart.enhancer_peaks_coord.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain dunnart.enhancer_smiCraTOmm10.bed enhancer_smiCraTOmm10_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/dunnart.promoter_peaks_coord.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain dunnart.promoter_smiCraTOmm10.bed promoter_smiCraTOmm10_unmapped.bed",intern=TRUE)
# enhancer = 437 peaks
# promoter = 48 peaks


## LiftOver peaks allowing for multiple matches
## Minimum target size is 50bp
## Minimum query size is 50bp

system("liftOver -bedPlus=3 -multiple -minChainT=100 -minChainQ=100 enhancers/dunnart_enhancer_peaks.narrowPeak ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/dunnart.enhancer_smiCraTOmm10.bed enhancers/enhancer_smiCraTOmm10_unmapped.bed",intern=TRUE)
## 29347
system("liftOver -bedPlus=3 -multiple -minChainT=100 -minChainQ=100 promoters/clustered/dunnart.clustered.narrowPeak ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/dunnart.promoter_smiCraTOmm10.bed promoters/clustered/promoter_smiCraTOmm10_unmapped.bed",intern=TRUE)
## 20191

# Import output files
enh = fread("enhancers/dunnart.enhancer_smiCraTOmm10.bed")
prom = fread("promoters/clustered/dunnart.promoter_smiCraTOmm10.bed")
data = list(enh, prom)
names(data) = c("enhancers", "promoters")
data = Map(mutate, data, cre = names(data))
data = lapply(data, function(x) x[order(V4),])
data = lapply(data, function(x) x=x[,width:=V3-V2])
data = rbindlist(data,)


###################################################################################################
################################### EXTRACT PEAK SUMMITS ########################################
###################################################################################################

# make list of peaks enhancer and promoter groups
system("less enhancers/dunnart_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}' | sort > enhancers/enhancer_peak_IDs.txt", intern=TRUE)
system("less promoters/clustered/dunnart.clustered.narrowPeak | awk -F '\t' '{print $4}' | sort > promoters/clustered/promoter_peak_IDs.txt", intern=TRUE)

system("cat /data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results_10M/macs2/H3K4me3_pooled_macs2_summits.bed /data/projects/punim0586/lecook/chipseq-pipeline/dunnart/results_10M/macs2/H3K27ac_pooled_macs2_summits.bed > H3K4me3_H3K27ac_combinedSummits.bed", intern=TRUE)

system("less E10.5_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}'  > E10.5_enhancer_peaks_IDs.txt",intern=TRUE)
system("less E11.5_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}'  > E11.5_enhancer_peaks_IDs.txt",intern=TRUE)
system("less E12.5_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}'  > E12.5_enhancer_peaks_IDs.txt",intern=TRUE)
system("less E13.5_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}'  > E13.5_enhancer_peaks_IDs.txt",intern=TRUE)
system("less E14.5_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}'  > E14.5_enhancer_peaks_IDs.txt",intern=TRUE)
system("less E15.5_enhancer_peaks.narrowPeak | awk -F '\t' '{print $4}'  > E15.5_enhancer_peaks_IDs.txt",intern=TRUE)

system("less  E10.5.clustered.narrowPeak | awk -F '\t' '{print $4}' > promoters/clustered/E10.5_promoter_peaks_IDs.txt",intern=TRUE)
system("less  E11.5.clustered.narrowPeak | awk -F '\t' '{print $4}'  > promoters/clustered/E11.5_promoter_peaks_IDs.txt",intern=TRUE)
system("less  E12.5.clustered.narrowPeak | awk -F '\t' '{print $4}'  > promoters/clustered/E12.5_promoter_peaks_IDs.txt",intern=TRUE)
system("less  E13.5.clustered.narrowPeak | awk -F '\t' '{print $4}'  > promoters/clustered/E13.5_promoter_peaks_IDs.txt",intern=TRUE)
system("less  E14.5.clustered.narrowPeak | awk -F '\t' '{print $4}'  > promoters/clustered/E14.5_promoter_peaks_IDs.txt",intern=TRUE)
system("less  E15.5.clustered.narrowPeak | awk -F '\t' '{print $4}'  > promoters/clustered/E15.5_promoter_peaks_IDs.txt",intern=TRUE)

setwd("/data/projects/punim0586/lecook/chipseq-pipeline/mouse/results_10M/macs2")
system("cat E10.5_H3K27ac.pooled.macs2_summits.bed E10.5_H3K4me3.pooled.macs2_summits.bed > ../../../cross_species/peakAnnotation/consensus/E10.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed", intern=TRUE)
system("cat E11.5_H3K27ac.pooled.macs2_summits.bed E11.5_H3K4me3.pooled.macs2_summits.bed > ../../../cross_species/peakAnnotation/consensus/E11.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed", intern=TRUE)
system("cat E12.5_H3K27ac.pooled.macs2_summits.bed E12.5_H3K4me3.pooled.macs2_summits.bed > ../../../cross_species/peakAnnotation/consensus/E12.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed", intern=TRUE)
system("cat E13.5_H3K27ac.pooled.macs2_summits.bed E13.5_H3K4me3.pooled.macs2_summits.bed > ../../../cross_species/peakAnnotation/consensus/E13.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed", intern=TRUE)
system("cat E14.5_H3K27ac.pooled.macs2_summits.bed E14.5_H3K4me3.pooled.macs2_summits.bed > ../../../cross_species/peakAnnotation/consensus/E14.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed", intern=TRUE)
system("cat E15.5_H3K27ac.pooled.macs2_summits.bed E15.5_H3K4me3.pooled.macs2_summits.bed > ../../../cross_species/peakAnnotation/consensus/E15.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed", intern=TRUE)

# in R extract rows from summits file based on the list of peaks in overlap file for both enhancers and promoters
## Dunnart

summits <- read.table("H3K4me3_H3K27ac_combinedSummits.bed")
reps1 <- scan("enhancers/enhancer_peak_IDs.txt", what="", sep="\n")
reps2 <- scan("promoters/clustered/promoter_peak_IDs.txt", what="", sep="\n")
enh_summits <- subset(summits, V4 %in% reps1)
pro_summits <- subset(summits, V4 %in% reps2)
write.table(enh_summits, "dunnart.enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(pro_summits, "dunnart.promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")

## Mouse
setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus")
E10 <- read.table("E10.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed")
E11<- read.table("E11.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed")
E12<- read.table("E12.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed")
E13<- read.table("E13.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed")
E14<- read.table("E14.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed")
E15<- read.table("E15.5_H3K27ac_H3K4me3.pooled.macs2_summits.bed")

p10 <- scan("promoters/clustered/E10.5_promoter_peaks_IDs.txt", what="", sep="\n")
p11 <- scan("promoters/clustered/E11.5_promoter_peaks_IDs.txt", what="", sep="\n")
p12 <- scan("promoters/clustered/E12.5_promoter_peaks_IDs.txt", what="", sep="\n")
p13 <- scan("promoters/clustered/E13.5_promoter_peaks_IDs.txt", what="", sep="\n")
p14 <- scan("promoters/clustered/E14.5_promoter_peaks_IDs.txt", what="", sep="\n")
p15 <- scan("promoters/clustered/E15.5_promoter_peaks_IDs.txt", what="", sep="\n")

e10 <- scan("enhancers/E10.5_enhancer_peaks_IDs.txt", what="", sep="\n")
e11 <- scan("enhancers/E11.5_enhancer_peaks_IDs.txt", what="", sep="\n")
e12 <- scan("enhancers/E12.5_enhancer_peaks_IDs.txt", what="", sep="\n")
e13 <- scan("enhancers/E13.5_enhancer_peaks_IDs.txt", what="", sep="\n")
e14 <- scan("enhancers/E14.5_enhancer_peaks_IDs.txt", what="", sep="\n")
e15 <- scan("enhancers/E15.5_enhancer_peaks_IDs.txt", what="", sep="\n")

write.table(subset(E10, V4 %in% p10), "promoters/clustered/E10_promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E11, V4 %in% p11), "promoters/clustered/E11_promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E12, V4 %in% p12), "promoters/clustered/E12_promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E13, V4 %in% p13), "promoters/clustered/E13_promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E14, V4 %in% p14), "promoters/clustered/E14_promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E15, V4 %in% p15), "promoters/clustered/E15_promoter_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")

write.table(subset(E10, V4 %in% e10), "enhancers/E10_enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E11, V4 %in% e11), "enhancers/E11_enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E12, V4 %in% e12), "enhancers/E12_enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E13, V4 %in% e13), "enhancers/E13_enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E14, V4 %in% e14), "enhancers/E14_enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
write.table(subset(E15, V4 %in% e15), "enhancers/E15_enhancer_overlap_summits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")


# in bash use bedtools to extend the summits 25bp in both directions to have 50bp 
system("bedtools slop -i enhancers/dunnart.enhancer_overlap_summits.bed -b 25 -g smiCra1.chrom.sizes > enhancers/enhancer_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i promoters/clustered/dunnart.promoter_overlap_summits.bed -b 25 -g smiCra1.chrom.sizes > promoters/clustered/promoter_overlap_50bpsummits.bed", intern=TRUE)

system("bedtools slop -i enhancers/E10_enhancer_overlap_summits.bed -b 25 -g mm10.chrom.sizes > enhancers/E10_enhancer_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i enhancers/E11_enhancer_overlap_summits.bed -b 25 -g mm10.chrom.sizes > enhancers/E11_enhancer_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i enhancers/E12_enhancer_overlap_summits.bed -b 25 -g mm10.chrom.sizes > enhancers/E12_enhancer_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i enhancers/E13_enhancer_overlap_summits.bed -b 25 -g mm10.chrom.sizes > enhancers/E13_enhancer_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i enhancers/E14_enhancer_overlap_summits.bed -b 25 -g mm10.chrom.sizes > enhancers/E14_enhancer_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i enhancers/E15_enhancer_overlap_summits.bed -b 25 -g mm10.chrom.sizes > enhancers/E15_enhancer_overlap_50bpsummits.bed", intern=TRUE)

system("bedtools slop -i promoters/clustered/E10_promoter_overlap_summits.bed -b 25 -g mm10.chrom.sizes > promoters/clustered/E10_promoter_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i promoters/clustered/E11_promoter_overlap_summits.bed -b 25 -g mm10.chrom.sizes > promoters/clustered/E11_promoter_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i promoters/clustered/E12_promoter_overlap_summits.bed -b 25 -g mm10.chrom.sizes > promoters/clustered/E12_promoter_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i promoters/clustered/E13_promoter_overlap_summits.bed -b 25 -g mm10.chrom.sizes > promoters/clustered/E13_promoter_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i promoters/clustered/E14_promoter_overlap_summits.bed -b 25 -g mm10.chrom.sizes > promoters/clustered/E14_promoter_overlap_50bpsummits.bed", intern=TRUE)
system("bedtools slop -i promoters/clustered/E15_promoter_overlap_summits.bed -b 25 -g mm10.chrom.sizes > promoters/clustered/E15_promoter_overlap_50bpsummits.bed", intern=TRUE)


###################################################################################################
################################### LIFTOVER PEAK SUMMITS ########################################
###################################################################################################

#### COMBINED PEAKS - ACTIVE IN BOTH DUNNART AND MOUSE ####

# LiftOver dunnart peaks to mouse genome
system("liftOver enhancers/enhancer_overlap_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/enhancer_summit50bp_smiCraTOmm10.bed enhancers/enhancer_summit50bp_smiCraTOmm10_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/promoter_overlap_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed promoters/clustered/promoter_summit50bp_smiCraTOmm10_unmapped.bed",intern=TRUE)

## Intersect dunnart CREs with mouse CREs.
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E10.5.clustered.narrowPeak -wo > promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E11.5.clustered.narrowPeak -wo > promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E12.5.clustered.narrowPeak -wo > promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E13.5.clustered.narrowPeak -wo > promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E14.5.clustered.narrowPeak -wo > promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E15.5.clustered.narrowPeak -wo > promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits.bed",intern=TRUE)

system("bedtools intersect -a enhancer_summit50bp_smiCraTOmm10.bed -b E10.5_enhancer_peaks.narrowPeak -wo > E10.5_enhancerOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancer_summit50bp_smiCraTOmm10.bed -b E11.5_enhancer_peaks.narrowPeak -wo > E11.5_enhancerOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancer_summit50bp_smiCraTOmm10.bed -b E12.5_enhancer_peaks.narrowPeak -wo > E12.5_enhancerOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancer_summit50bp_smiCraTOmm10.bed -b E13.5_enhancer_peaks.narrowPeak -wo > E13.5_enhancerOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancer_summit50bp_smiCraTOmm10.bed -b E14.5_enhancer_peaks.narrowPeak -wo > E14.5_enhancerOverlapmm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancer_summit50bp_smiCraTOmm10.bed -b E15.5_enhancer_peaks.narrowPeak -wo > E15.5_enhancerOverlapmm10_50bpsummits.bed",intern=TRUE)

## Lift dunnart peaks back over to the dunnart genome
system("liftOver -bedPlus=4 promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)

system("liftOver -bedPlus=4 enhancers/E10.5_enhancerOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed enhancers/E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E11.5_enhancerOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E11.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed enhancers/E11.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E12.5_enhancerOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E12.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed enhancers/E12.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E13.5_enhancerOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E13.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed enhancers/E13.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E14.5_enhancerOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E14.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed enhancers/E14.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E15.5_enhancerOverlapmm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E15.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed enhancers/E15.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)

awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E11.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E12.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E13.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E15.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E14.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed

# E11.5_H3K27ac.pooled.macs2_peak_13476 is duplicated
# scaffold00030_pilon_pilon       15206485        15206536        H3K27ac_pooled_macs2_peak_99049 13.07934        chr16   44615130        44617625        E11.5_H3K27ac.pooled.macs2_peak_13476       269     .       10.16625        26.91089        23.58920        1194    51
# scaffold00030_pilon_pilon       15207575        15207626        H3K27ac_pooled_macs2_peak_99050 28.62918        chr16   44615130        44617625        E11.5_H3K27ac.pooled.macs2_peak_13476       269     .       10.16625        26.91089        23.58920        1194    51

# E11.5_H3K27ac.pooled.macs2_peak_10317 is duplicated
# scaffold00002_pilon_pilon       130541237       130541288       H3K27ac_pooled_macs2_peak_13645 10.08028        chr14   24825909        24828470        E11.5_H3K27ac.pooled.macs2_peak_10317       372     .       12.48566        37.24145        33.69604        1973    52
# scaffold00164_pilon_pilon       1438896 1438947 H3K27ac_pooled_macs2_peak_150856        6.25556 chr14   24825909        24828470        E11.5_H3K27ac.pooled.macs2_peak_10317       372     .       12.48566        37.24145        33.69604        1973    51

# E12.5_H3K27ac.pooled.macs2_peak_25988 is duplicated
# scaffold00030_pilon_pilon       15206485        15206536        H3K27ac_pooled_macs2_peak_99049 13.07934        chr16   44615052        44618395        E12.5_H3K27ac.pooled.macs2_peak_25988       428     .       14.73608        42.88547        39.11777        1216    51
# scaffold00030_pilon_pilon       15207575        15207626        H3K27ac_pooled_macs2_peak_99050 28.62918        chr16   44615052        44618395        E12.5_H3K27ac.pooled.macs2_peak_25988       428     .       14.73608        42.88547        39.11777        1216    51

# E13.5_H3K27ac.pooled.macs2_peak_35104 is duplicated
# scaffold00030_pilon_pilon       15206485        15206536        H3K27ac_pooled_macs2_peak_99049 13.07934        chr16   44615114        44617699        E13.5_H3K27ac.pooled.macs2_peak_35104       357     .       9.00248 35.75615        32.52668        1721    51
# scaffold00030_pilon_pilon       15207575        15207626        H3K27ac_pooled_macs2_peak_99050 28.62918        chr16   44615114        44617699        E13.5_H3K27ac.pooled.macs2_peak_35104       357     .       9.00248 35.75615        32.52668        1721    51

# E13.5_H3K27ac.pooled.macs2_peak_26554 is duplicated
# scaffold00002_pilon_pilon       130541237       130541288       H3K27ac_pooled_macs2_peak_13645 10.08028        chr14   24825799        24828390        E13.5_H3K27ac.pooled.macs2_peak_26554       324     .       11.76375        32.42406        29.25455        758     52
# scaffold00164_pilon_pilon       1438896 1438947 H3K27ac_pooled_macs2_peak_150856        6.25556 chr14   24825799        24828390        E13.5_H3K27ac.pooled.macs2_peak_26554       324     .       11.76375        32.42406        29.25455        758     51

# E14.5_H3K27ac.pooled.macs2_peak_24514 is duplicated
# scaffold00030_pilon_pilon       15206485        15206536        H3K27ac_pooled_macs2_peak_99049 13.07934        chr16   44614943        44618063        E14.5_H3K27ac.pooled.macs2_peak_24514       544     .       11.99538        54.44302        51.09379        1990    51
# scaffold00030_pilon_pilon       15207575        15207626        H3K27ac_pooled_macs2_peak_99050 28.62918        chr16   44614943        44618063        E14.5_H3K27ac.pooled.macs2_peak_24514       544     .       11.99538        54.44302        51.09379        1990    51

# E14.5_H3K27ac.pooled.macs2_peak_18551 is duplicated
# scaffold00002_pilon_pilon       130541237       130541288       H3K27ac_pooled_macs2_peak_13645 10.08028        chr14   24825764        24828307        E14.5_H3K27ac.pooled.macs2_peak_18551       263     .       10.19783        26.37918        23.49332        1742    52
# scaffold00164_pilon_pilon       1438896 1438947 H3K27ac_pooled_macs2_peak_150856        6.25556 chr14   24825764        24828307        E14.5_H3K27ac.pooled.macs2_peak_18551       263     .       10.19783        26.37918        23.49332        1742    51

# E15.5_H3K27ac.pooled.macs2_peak_20587 is duplicated
# scaffold00030_pilon_pilon       15206485        15206536        H3K27ac_pooled_macs2_peak_99049 13.07934        chr16   44615161        44617589        E15.5_H3K27ac.pooled.macs2_peak_20587       254     .       10.70462        25.49718        22.21071        1155    51
# scaffold00030_pilon_pilon       15207575        15207626        H3K27ac_pooled_macs2_peak_99050 28.62918        chr16   44615161        44617589        E15.5_H3K27ac.pooled.macs2_peak_20587       254     .       10.70462        25.49718        22.21071        1155    51

awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E10.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E11.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E12.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E13.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E15.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed
awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E14.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed

# E14.5_H3K4me3.pooled.macs2_peak_8068 is duplicated
# scaffold00098_pilon_pilon       5322430 5322481 H3K4me3_pooled_macs2_peak_110310        7.99621 chr15   8443049 8445832 E14.5_H3K4me3.pooled.macs2_peak_8068    3775    .  73.91695 377.57697       372.49487       1968    51
# scaffold00200_pilon_pilon       318471  318522  H3K4me3_pooled_macs2_peak_125887        197.97865       chr15   8443049 8445832 E14.5_H3K4me3.pooled.macs2_peak_8068    3775.       73.91695        377.57697       372.49487       1968    53

#### DUNNART SPECIFIC PEAKS - ACTIVE ONLY IN THE DUNNART ####
## Intersect dunnart CREs with mouse CREs keeping those that DO NOT overlap.

system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E10.5.clustered.narrowPeak -v > promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E11.5.clustered.narrowPeak -v > promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E12.5.clustered.narrowPeak -v > promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E13.5.clustered.narrowPeak -v > promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E14.5.clustered.narrowPeak -v > promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/promoter_summit50bp_smiCraTOmm10.bed -b promoters/clustered/E15.5.clustered.narrowPeak -v > promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)

system("bedtools intersect -a enhancers/enhancer_summit50bp_smiCraTOmm10.bed -b enhancers/E10.5_enhancer_peaks.narrowPeak -v > enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/enhancer_summit50bp_smiCraTOmm10.bed -b enhancers/E11.5_enhancer_peaks.narrowPeak -v > enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/enhancer_summit50bp_smiCraTOmm10.bed -b enhancers/E12.5_enhancer_peaks.narrowPeak -v > enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/enhancer_summit50bp_smiCraTOmm10.bed -b enhancers/E13.5_enhancer_peaks.narrowPeak -v > enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/enhancer_summit50bp_smiCraTOmm10.bed -b enhancers/E14.5_enhancer_peaks.narrowPeak -v > enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/enhancer_summit50bp_smiCraTOmm10.bed -b enhancers/E15.5_enhancer_peaks.narrowPeak -v > enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits.bed",intern=TRUE)

## Lift dunnart-specific peaks back over to the dunnart genome
system("liftOver -bedPlus=4 promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)

system("liftOver -bedPlus=4 enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_unmapped.bed",intern=TRUE)


#### MOUSE SPECIFIC PEAKS - ACTIVE ONLY IN THE MOUSE ####

# LiftOver mouse peaks to dunnart genome
system("liftOver enhancers/E10_enhancer_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E10_enhancer_summit50bp_mm10TOsmiCra.bed enhancers/E10_enhancer_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver enhancers/E11_enhancer_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E11_enhancer_summit50bp_mm10TOsmiCra.bed enhancers/E11_enhancer_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver enhancers/E12_enhancer_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E12_enhancer_summit50bp_mm10TOsmiCra.bed enhancers/E12_enhancer_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver enhancers/E13_enhancer_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E13_enhancer_summit50bp_mm10TOsmiCra.bed enhancers/E13_enhancer_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver enhancers/E14_enhancer_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E14_enhancer_summit50bp_mm10TOsmiCra.bed enhancers/E14_enhancer_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver enhancers/E15_enhancer_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E15_enhancer_summit50bp_mm10TOsmiCra.bed enhancers/E15_enhancer_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)

system("liftOver promoters/clustered/E10_promoter_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E10_promoter_summit50bp_mm10TOsmiCra.bed promoters/clustered/E10_promoter_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/E11_promoter_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E11_promoter_summit50bp_mm10TOsmiCra.bed promoters/clustered/E11_promoter_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/E12_promoter_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E12_promoter_summit50bp_mm10TOsmiCra.bed promoters/clustered/E12_promoter_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/E13_promoter_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E13_promoter_summit50bp_mm10TOsmiCra.bed promoters/clustered/E13_promoter_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/E14_promoter_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E14_promoter_summit50bp_mm10TOsmiCra.bed promoters/clustered/E14_promoter_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)
system("liftOver promoters/clustered/E15_promoter_overlap_50bpsummits.bed ../mm10TOsmiCra1_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E15_promoter_summit50bp_mm10TOsmiCra.bed promoters/clustered/E15_promoter_summit50bp_mm10TOsmiCra_unmapped.bed",intern=TRUE)

## Intersect dunnart CREs with mouse CREs keeping those that DO NOT overlap.
system("bedtools intersect -a promoters/clustered/E10_promoter_summit50bp_mm10TOsmiCra.bed -b promoters/clustered/dunnart.clustered.narrowPeak -v > promoters/clustered/E10.5_promoter_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/E11_promoter_summit50bp_mm10TOsmiCra.bed -b promoters/clustered/dunnart.clustered.narrowPeak -v > promoters/clustered/E11.5_promoter_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/E12_promoter_summit50bp_mm10TOsmiCra.bed -b promoters/clustered/dunnart.clustered.narrowPeak -v > promoters/clustered/E12.5_promoter_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/E13_promoter_summit50bp_mm10TOsmiCra.bed -b promoters/clustered/dunnart.clustered.narrowPeak -v > promoters/clustered/E13.5_promoter_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/E14_promoter_summit50bp_mm10TOsmiCra.bed -b promoters/clustered/dunnart.clustered.narrowPeak -v > promoters/clustered/E14.5_promoter_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a promoters/clustered/E15_promoter_summit50bp_mm10TOsmiCra.bed -b promoters/clustered/dunnart.clustered.narrowPeak -v > promoters/clustered/E15.5_promoter_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)

system("bedtools intersect -a enhancers/E10_enhancer_summit50bp_mm10TOsmiCra.bed -b enhancers/dunnart_enhancer_peaks.narrowPeak -v > enhancers/E10.5_enhancer_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/E11_enhancer_summit50bp_mm10TOsmiCra.bed -b enhancers/dunnart_enhancer_peaks.narrowPeak -v > enhancers/E11.5_enhancer_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/E12_enhancer_summit50bp_mm10TOsmiCra.bed -b enhancers/dunnart_enhancer_peaks.narrowPeak -v > enhancers/E12.5_enhancer_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/E13_enhancer_summit50bp_mm10TOsmiCra.bed -b enhancers/dunnart_enhancer_peaks.narrowPeak -v > enhancers/E13.5_enhancer_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/E14_enhancer_summit50bp_mm10TOsmiCra.bed -b enhancers/dunnart_enhancer_peaks.narrowPeak -v > enhancers/E14.5_enhancer_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)
system("bedtools intersect -a enhancers/E15_enhancer_summit50bp_mm10TOsmiCra.bed -b enhancers/dunnart_enhancer_peaks.narrowPeak -v > enhancers/E15.5_enhancer_mouse.specific_smiCra_50bpsummits.bed",intern=TRUE)

## Lift mouse-specific peaks back over to the mouse genome
system("liftOver -bedPlus=4 promoters/clustered/E10.5_promoter_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E10.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10.bed promoters/clustered/E10.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E11.5_promoter_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E11.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10.bed promoters/clustered/E11.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E12.5_promoter_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E12.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10.bed promoters/clustered/E12.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E13.5_promoter_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E13.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10.bed promoters/clustered/E13.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E14.5_promoter_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E14.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10.bed promoters/clustered/E14.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E15.5_promoter_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E15.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10.bed promoters/clustered/E15.5_promoter_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)

system("liftOver -bedPlus=4 enhancers/E10.5_enhancer_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E10.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10.bed enhancers/E10.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E11.5_enhancer_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E11.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10.bed enhancers/E11.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E12.5_enhancer_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E12.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10.bed enhancers/E12.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E13.5_enhancer_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E13.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10.bed enhancers/E13.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E14.5_enhancer_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E14.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10.bed enhancers/E14.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E15.5_enhancer_mouse.specific_smiCra_50bpsummits.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E15.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10.bed enhancers/E15.5_enhancer_mouse.specific_smiCra_50bpsummits_backTOmm10_unmapped.bed",intern=TRUE)

## Lift dunnart-specific peaks and combined peaks back into mm10 coordinates for GREAT analysis
system("liftOver -bedPlus=4 promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E10.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E11.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E12.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E13.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E14.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E15.5.clustered_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)

system("liftOver -bedPlus=4 enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E10.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E11.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E12.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E13.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E14.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E15.5_enhancer_dunnart.specific_mm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)

## Combined peaks

system("liftOver -bedPlus=4 promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E10.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E11.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E12.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E13.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E14.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed promoters/clustered/E15.5_promoterOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)

system("liftOver -bedPlus=4 enhancers/E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E11.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E11.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E11.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E12.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E12.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E12.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E13.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E13.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E13.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E14.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E14.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E14.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)
system("liftOver -bedPlus=4 enhancers/E15.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed ../smiCra1TOmm10_patched_sorted_repFil_chainCl_preNet_chainNet_stitched.chain enhancers/E15.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10.bed enhancers/E15.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra_backTOmm10_unmapped.bed",intern=TRUE)


###################################################################################################
################################### INTERSECT IDS FROM OVERLAPS ###################################
###################################################################################################





###################################################################################################
############################### GENE ONTOLOGY & PATHWAY ANALYSIS ##################################
###################################################################################################
##  Using mouse coordinates for the peaks, use GREAT to look for the nearest gene TSS
##  Then use clusterProfiler to look at Gene Ontology enrichment in the mouse, dunnart and combined peak sets

library(rGREAT)
library(clusterProfiler)
library(data.table)


great <- function(bedList){
    bedFiles = list.files(bedList, pattern= ".bed", full.names=T) # create list of files in directory
    bedFiles = as.list(bedFiles)
    data = lapply(bedFiles, function(x) fread(x, header=TRUE, sep="\t", quote = "") %>% as.data.table()) # read in all files
    data = lapply(data, function(x) submitGreatJob(x, species = "mm10")) # submit GREAT jobs
    names(data) = c("E10:mouse", "E10:combined", "E10:dunnart", "E11:mouse", "E11:combined", "E11:dunnart",
    "E12:mouse", "E12:combined", "E12:dunnart", "E13:mouse", "E13:combined", "E13:dunnart", 
    "E14:mouse", "E14:combined", "E14:dunnart", "E15:mouse", "E15:combined", "E15:dunnart")

    data = Map(mutate, data, group = names(data)) ## add column with group names

    databind = rbindlist(data,) #bind dataframes together
    split_by_stage = databind[
     ,c("stage", "species") := tstrsplit(group, ":", fixed=TRUE)
     ][
       ,'group':=NULL
       ]


}




## For each mouse stage have a list of peak IDs

# ## Scan IDs into an object
# setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/consensus/enhancers")
# E10 <- scan("E10.5_enhancerOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E11 <- scan("E11.5_enhancerOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E12 <- scan("E12.5_enhancerOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E13 <- scan("E13.5_enhancerOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E14 <- scan("E14.5_enhancerOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E15 <- scan("E15.5_enhancerOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")

# ## Look for dunnart peak IDs that overlap with mouse embryonic stages in the mouse peaks that overlap with the dunnart peaks at P0
# # E10.5_enhancerOverlapsmiCra_50bpsummits.bed file:
# # chr8    121436317       121436374       H3K27ac_pooled_macs2_peak_644   9.64793 chr8    121436230       121436873       E10.5_H3K27ac.pooled.macs2_peak_77013   75      .       4.66414 7.52876 5.17964 305     57

# write.table(subset(read.table("E10.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E10) %in% V4), file = "E10.5_enhancerOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E11.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E11) %in% V4), file = "E11.5_enhancerOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E12.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E12) %in% V4), file = "E12.5_enhancerOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E13.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E13) %in% V4), file = "E13.5_enhancerOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E14.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E14) %in% V4), file = "E14.5_enhancerOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E15.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E15) %in% V4), file = "E15.5_enhancerOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")

# ## Mouse CREs with dunnart coordinates that aren't active in dunnart at P0
# ## Do I use only those that are reproducible (eg. found in both lists)or even those that I overlapped from mouse to dunnart but not in the finally overlap??

# write.table(subset(read.table("E10.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4)), file = "E10.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E11.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4)), file = "E11.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E12.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4), file = "E12.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E13.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4)), file = "E13.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E14.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4)), file = "E14.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E15.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4)), file = "E15.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")

# ## Not in list dunnart CREs
# write.table(subset(read.table("E10.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(E10 %in% V4)), file = "E10.5_enhancerNoOverlasmiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E11.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(V4 %in% E11)), file = "E11.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E12.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(V4 %in% E12), file = "E12.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E13.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(V4 %in% E13)), file = "E13.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E14.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(V4 %in% E14)), file = "E14.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E15.5_enhancerOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), !(V4 %in% E15)), file = "E15.5_enhancerNoOverlapmm10_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")

# ## Promoters
# setwd("/data/projects/punim0586/lecook/chipseq-pipeline/cross_species/peakAnnotation/overlaps/promoters/clustered/")
# E10 <- scan("E10.5_promoterOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E11 <- scan("E11.5_promoterOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E12 <- scan("E12.5_promoterOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E13 <- scan("E13.5_promoterOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E14 <- scan("E14.5_promoterOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")
# E15 <- scan("E15.5_promoterOverlapmm10_50bpsummitsIDs.txt", what="", sep="\n")

# ## Look for dunnart peak IDs that overlap with mouse embryonic stages in the mouse peaks that overlap with the dunnart peaks at P0
# write.table(subset(read.table("E10.5_promoterOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E10) %in% V4), file = "E10.5_promoterOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E11.5_promoterOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E11) %in% V4), file = "E11.5_promoterOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E12.5_promoterOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E12) %in% V4), file = "E12.5_promoterOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E13.5_promoterOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E13) %in% V4), file = "E13.5_promoterOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E14.5_promoterOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E14) %in% V4), file = "E14.5_promoterOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")
# write.table(subset(read.table("E15.5_promoterOverlapsmiCra_50bpsummits.bed", sep="\t", quote="", header=FALSE), unique(E15) %in% V4), file = "E15.5_promoterOverlapmm10_smiCra1_50bpsummits.bed", quote=FALSE, col.names=FALSE, row.names=FALSE, sep="\t")

# ## Check duplicates
# awk 'x[$4]++ == 1 { print $4 " is duplicated"}' E10.5_enhancerOverlapmm10_50bpsummits.bed
# awk 'x[$4]++ == 1 { print $4 " is duplicated"}' E11.5_enhancerOverlapmm10_50bpsummits.bed
# awk 'x[$4]++ == 1 { print $4 " is duplicated"}' E12.5_enhancerOverlapmm10_50bpsummits.bed
# awk 'x[$4]++ == 1 { print $4 " is duplicated"}' E13.5_enhancerOverlapmm10_50bpsummits.bed
# awk 'x[$4]++ == 1 { print $4 " is duplicated"}' E15.5_enhancerOverlapmm10_50bpsummits.bed
# awk 'x[$4]++ == 1 { print $4 " is duplicated"}' E14.5_enhancerOverlapmm10_50bpsummits.bed




# awk 'x[$9]++ == 1 { print $9 " is duplicated"}' E10.5_enhancerOverlapmm10_50bpsummits_backTOsmiCra.bed