## Laura Cook 2021
## This script takes separate annotation peak text files, extracts the geneIDs and intersects them
## The intersection of geneIds between the different samples is then plotted using an upset plot

# Load in libraries
library(data.table) 
library(tidyverse)
library(ggridges)
library(ggpubr)
library(reshape2)
library(RColorBrewer)
library(ggplot2)
library(VennDiagram)
library(viridis)
library(hrbrthemes)
library(gghalves)
library(ComplexHeatmap)
library(plyr)
library(UpSetR)

setwd("../../../cross_species/peakAnnotation/")

geneSetUpset <- function(fileList, plot){
    files =list.files(fileList, pattern= ".txt", full.names=T) # create list of files in directory
    files = as.list(files)
    data = lapply(files, function(x) fread(x, header=TRUE, sep="\t", quote = "", na.strings=c("", "NA"))) # read in all files
    names(data) = c("P0","E10.5","E11.5","E12.5", "E13.5","E14.5", "E15.5")
    data$P0$group <- "dunnart"
    data = lapply(data, function(x) x=setnames(x, old="geneId", new="mouseensembl", skip_absent=TRUE) %>% as.data.table())
    subset = lapply(data, function(x) x %>% dplyr::select(mouseensembl) %>% as.data.table() %>% unique())
    df1 = Map(mutate, subset, stage = names(subset)) 
    merged <- df1 %>% purrr::reduce(full_join, by = "mouseensembl")  # join all dataframes by ensembl geneID
    merged[is.na(merged)] <- 0
    merged = as.data.frame(merged)
    colnames(merged) = c("geneId", "P0", "E10.5", "E11.5", "E12.5", "E13.5", "E14.5", "E15.5")
    geneId = merged$geneId
    upset.df = data.frame(lapply(merged[,2:8], function(x) as.numeric(x!="0")))
    rownames(upset.df) = geneId

    pdf(plot)
    print(upset(upset.df, nsets=7, order.by="freq", number.angles = 45,
    queries = list(list(
        query = elements,
        params = list("genomic_annotation"),
        color = "#Df5286",
        query.name = "Genomic annotation"
    ))))
    dev.off()
}

geneSetUpset(fileList = "consensus/promoters/clustered", plot = "promoters_upsetPlot.pdf")
geneSetUpset(fileList = "consensus/enhancers/annotation", plot = "enhancers_upsetPlot.pdf")


## Overlap between enhancers and promoters
vennDiagrams <- function(enhancers, promoters, plotName){
    enhancers = fread(enhancers)
    promoters = fread(promoters)
    enhancers = enhancers=setnames(enhancers, old="geneId", new="mouseensembl", skip_absent=TRUE) %>% as.data.table()
    promoters = promoters=setnames(promoters, old="geneId", new="mouseensembl", skip_absent=TRUE) %>% as.data.table()

    enhancerIDs = unique(enhancers$mouseensembl)
    promoterIDs = unique(promoters$mouseensembl)
    venn.diagram(
      x = list(enhancerIDs, promoterIDs),
      category.names = c("enhancers" , "promoters"),
      filename = plotName,
      output=TRUE)
}

vennDiagrams(enhancers="consensus/enhancers/annotation/E10.5_enhancer_annotation.txt", 
promoters="consensus/promoters/clustered/clustered.E10.filtered_annotation.txt", 
plotName="E10_cre_vennDiagram.png")

vennDiagrams(enhancers="consensus/enhancers/annotation/E11.5_enhancer_annotation.txt", 
promoters="consensus/promoters/clustered/clustered.E11.filtered_annotation.txt", 
plotName="E11_cre_vennDiagram.png")

vennDiagrams(enhancers="consensus/enhancers/annotation/E12.5_enhancer_annotation.txt", 
promoters="consensus/promoters/clustered/clustered.E12.filtered_annotation.txt", 
plotName="E12_cre_vennDiagram.png")

vennDiagrams(enhancers="consensus/enhancers/annotation/E13.5_enhancer_annotation.txt", 
promoters="consensus/promoters/clustered/clustered.E13.filtered_annotation.txt", 
plotName="E13_cre_vennDiagram.png")

vennDiagrams(enhancers="consensus/enhancers/annotation/E14.5_enhancer_annotation.txt", 
promoters="consensus/promoters/clustered/clustered.E14.filtered_annotation.txt", 
plotName="E14_cre_vennDiagram.png")

vennDiagrams(enhancers="consensus/enhancers/annotation/E15.5_enhancer_annotation.txt", 
promoters="consensus/promoters/clustered/clustered.E15.filtered_annotation.txt", 
plotName="E15_cre_vennDiagram.png")

vennDiagrams(enhancers="consensus/enhancers/annotation/dunnart_enhancer_annotationConvertedIDs.txt", 
promoters="consensus/promoters/clustered/cluster1_promoters_annotationConvertedIDs.txt", 
plotName="dunnart_cre_vennDiagram.png")