
## Import packages
library(data.table)
library(ggplot2)

## Create datatable with peak overlap counts

promoters = data.table(
    samples = c("E10.5","E11.5","E12.5","E13.5","E14.5","E15.5"),
    liftOver.total = rep(as.numeric(1881), 6),
    common.peaks = c(923,882,892,854,907,821)
  )

enhancers = data.table(
    samples = c("E10.5","E11.5","E12.5","E13.5","E14.5","E15.5"),
    liftOver.total = rep(as.numeric(3820), 6),
    common.peaks = c(123, 72, 104, 161, 122, 66)
)

## Combine into a list
list = list(promoters, enhancers)
list[[1]]$cre = "promoters"
list[[2]]$cre = "enhancers"

## Add peaks active at each stage as a fraction of all peaks that can be reciprocally lifted over
list = lapply(list, function(x) transform(x, peakFraction = (common.peaks / liftOver.total)*100))

## Merge datatables and then plot peak fractions
df = rbindlist(list, )
pdf("liftOver_peaks.pdf", width=10, height=6)
ggplot(df, aes(fill=cre, y=peakFraction, x=samples)) + 
    geom_bar(position="dodge", stat="identity")
dev.off()

